@@ -1,4 +1,7 @@
 from .accounts._client import _Client as Client
+from .accounts.methods import Methods
+from .bots.methods import Methods as BotMethods
+from .accounts import Message
 from .bots import _Client as Bot
 from .crypto import Crypto
 from .util import Utils
@@ -8,8 +11,9 @@ from .exceptions import (
     TooRequests,
     Repeated,
     NotRegistered,
+    APIException,
 )
 
 
-__version__ = '5.1.1'
+__version__ = '5.2.0'
 __author__ = 'Shayan Heidari'
\ No newline at end of file
