@@ -1,4 +1,6 @@
 from ..connections import Connections
+from aiohttp import ClientSession
+from urllib3 import PoolManager
 from ...crypto import Crypto
 from random import randint
 from ...util import Utils
@@ -15,7 +17,7 @@ from ...exceptions import (
 class Maker:
     def __init__(self, auth, session):
         self.auth = auth
-        self.session = session
+        self.session: ClientSession = session
         self.connections = Connections()
         self.crypto = Crypto(auth)
 
@@ -51,7 +53,9 @@ class Maker:
             elif status_det == 'INVALID_INPUT':
                 raise InvalidInput('The data sent to the server is wrong')
             elif status_det == 'INVALID_AUTH':
-                raise InvaildAuth('An error was received from the server side, probably the data sent is wrong or your AUTH is invalid')
+                raise InvaildAuth(
+                    'This error usually occurs because you do not have the required access to perform the operation, for example, you do not have access to send messages to the group.'
+                )
             elif status_det == 'TOO_REQUESTS':
                 raise TooRequests('Unfortunately, your account has been limited')
             elif status_det.lower() == 'repeated':
@@ -107,17 +111,19 @@ class Maker:
                     return response.get('data').get('access_hash_rec')
 
 class Methods:
-    def __init__(self, auth, session):
+    def __init__(self, auth, session, account_guid):
         self.auth = auth
-        self.session = session
+        self.session: ClientSession = session
+        self.account_guid = account_guid
         self.make = Maker(auth=auth, session=session)
         self.utils = Utils()
+        self.PoolManager = PoolManager()
 
     async def __aenter__(self):
         return self
 
     async def __aexit__(self, exc_type, exc_val, exc_tb):
-        print(exc_type, exc_val, exc_tb)
+        pass
 
     # Messages
     async def sendText(self, object_guid, text, reply_to_message_id=None, mention=None):
@@ -784,12 +790,12 @@ class Methods:
     async def download(self, object_guid, message_id, save=False):
         message_info = await self.getMessagesByID(object_guid=object_guid, message_ids=[message_id])
         message_info = message_info.get('messages')[0]
+
         if 'file_inline' in list(message_info.keys()):
             message_info = message_info.get('file_inline')
             dc_id = message_info.get('dc_id')
             access_hash_rec = message_info.get('access_hash_rec')
             file_id = message_info.get('file_id')
-            size = message_info.get('size')
             file_name = message_info.get('file_name')
             makeURL = f'https://messenger{dc_id}.iranlms.ir/GetFile.ashx'
             data = b''
@@ -797,36 +803,34 @@ class Methods:
             headers = {
                 'auth': self.auth,
                 'file-id': file_id,
-                'start-index': '0',
-                'last-index': str(size),
                 'access-hash-rec': access_hash_rec,
+                'client-app-version': '3.0.6',
+                'client-platform': 'Android',
+                'client-app-name': 'Main',
+                'client-package': 'app.rbmain.a',
+                'clinet-user-guid': self.account_guid if self.account_guid != None else '',
+                'Content-Type': 'application/json',
+                'User-Agent': 'okhttp/3.12.1',
             }
-            start_index = 0
 
-            while True:
-                if start_index <= 131072:
-                    headers['start-index'], headers['last-index'] = '0', str(size)
-                    data += await self.make.connections._download(
-                        session=self.session,
-                        url=makeURL,
-                        headers=headers
-                    )
+            if save:
+                with open(file_name, 'wb+') as file:
+                    file.close()
+
+            with self.PoolManager.request(
+                method='POST',
+                url=makeURL,
+                headers=headers,
+                preload_content=False,
+            ) as response:
+                for chunk in response.stream(524284):
                     if save:
-                        with open(file_name, 'wb+') as my_file:
-                            my_file.write(data)
-                            my_file.close()
-                            return True
+                        with open(file_name, 'ab+') as file:
+                            file.write(chunk)
+                            file.close()
                     else:
-                        return data
-
+                        data += chunk
+                if save:
+                    return True
                 else:
-                    for i in range(0, size, 131072):
-                        headers['start-index'], headers['last-index'] = str(i), str(i + 131072 if i + 131072 <= size else size)
-                        data += await self.make.connections._download(
-                            session=self.session,
-                            url=makeURL,
-                            headers=headers
-                        )
-                        continue
-        else:
-            return None
\ No newline at end of file
+                    return data
\ No newline at end of file
